diff --git a/.gitignore b/.gitignore
index 890f4df..8105fe8 100644
--- a/.gitignore
+++ b/.gitignore
@@ -23,12 +23,8 @@ bld/
[Oo]bj/
# Intermidate Building Things
-BetterCells/[Dd]ebug - Disk/
-BetterCells/[Dd]ebug - Steam Patched/
-BetterCells/[Dd]ebug - Steam/
-BetterCells/[Rr]elease - Disk/
-BetterCells/[Rr]elease - Steam Patched/
-BetterCells/[Rr]elease - Steam/
+CellStagePartsAPI/[Dd]ebug/
+CellStagePartsAPI/[Rr]elease/
# Visual Studio 2015 cache/options directory
.vs/
diff --git a/BetterCells.sln b/CellStagePartsAPI.sln
similarity index 90%
rename from BetterCells.sln
rename to CellStagePartsAPI.sln
index e8a0387..4d7869c 100644
--- a/BetterCells.sln
+++ b/CellStagePartsAPI.sln
@@ -3,7 +3,7 @@ Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio Version 16
VisualStudioVersion = 16.0.29728.190
MinimumVisualStudioVersion = 10.0.40219.1
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "BetterCells", "BetterCells\BetterCells.vcxproj", "{07FC5B61-B575-4207-B464-AFAE6AF3FC19}"
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "CellStagePartsAPI", "CellStagePartsAPI\CellStagePartsAPI.vcxproj", "{07FC5B61-B575-4207-B464-AFAE6AF3FC19}"
ProjectSection(ProjectDependencies) = postProject
{F057451A-1413-4D68-AF56-1BF529933420} = {F057451A-1413-4D68-AF56-1BF529933420}
EndProjectSection
diff --git a/BetterCells/BetterCells.vcxproj b/CellStagePartsAPI/CellStagePartsAPI.vcxproj
similarity index 97%
rename from BetterCells/BetterCells.vcxproj
rename to CellStagePartsAPI/CellStagePartsAPI.vcxproj
index 8b744c9..efa95e5 100644
--- a/BetterCells/BetterCells.vcxproj
+++ b/CellStagePartsAPI/CellStagePartsAPI.vcxproj
@@ -13,8 +13,9 @@
{07FC5B61-B575-4207-B464-AFAE6AF3FC19}
Win32Proj
- BetterCells
+ CellStagePlusAPI
10.0
+ CellStagePartsAPI
@@ -99,12 +100,12 @@
-
+
-
+
false
diff --git a/BetterCells/BetterCells.vcxproj.filters b/CellStagePartsAPI/CellStagePartsAPI.vcxproj.filters
similarity index 82%
rename from BetterCells/BetterCells.vcxproj.filters
rename to CellStagePartsAPI/CellStagePartsAPI.vcxproj.filters
index 9314442..552599e 100644
--- a/BetterCells/BetterCells.vcxproj.filters
+++ b/CellStagePartsAPI/CellStagePartsAPI.vcxproj.filters
@@ -5,12 +5,12 @@
{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}
rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms
-
- {3880d018-2395-4502-abfe-4b83e0817aab}
-
{d62ad12d-69d8-4933-8342-03043c9adc22}
+
+ {3880d018-2395-4502-abfe-4b83e0817aab}
+
@@ -19,19 +19,19 @@
Internal
-
- BetterCells
+
+ CellStagePartsAPI
- BetterCells
+ CellStagePartsAPI
Internal
-
- BetterCells
+
+ CellStagePartsAPI
diff --git a/BetterCells/ReadMe.txt b/CellStagePartsAPI/ReadMe.txt
similarity index 81%
rename from BetterCells/ReadMe.txt
rename to CellStagePartsAPI/ReadMe.txt
index 4232120..ffab27b 100644
--- a/BetterCells/ReadMe.txt
+++ b/CellStagePartsAPI/ReadMe.txt
@@ -1,20 +1,20 @@
========================================================================
- DYNAMIC LINK LIBRARY : BetterCells Project Overview
+ DYNAMIC LINK LIBRARY : CellStagePartsAPI Project Overview
========================================================================
-AppWizard has created this BetterCells DLL for you.
+AppWizard has created this CellStagePartsAPI DLL for you.
This file contains a summary of what you will find in each of the files that
-make up your BetterCells application.
+make up your CellStagePartsAPI application.
-BetterCells.vcxproj
+CellStagePartsAPI.vcxproj
This is the main project file for VC++ projects generated using an Application Wizard.
It contains information about the version of Visual C++ that generated the file, and
information about the platforms, configurations, and project features selected with the
Application Wizard.
-BetterCells.vcxproj.filters
+CellStagePartsAPI.vcxproj.filters
This is the filters file for VC++ projects generated using an Application Wizard.
It contains information about the association between the files in your project
and the filters. This association is used in the IDE to show grouping of files with
@@ -26,7 +26,7 @@ Other standard files:
StdAfx.h, StdAfx.cpp
These files are used to build a precompiled header (PCH) file
- named BetterCells.pch and a precompiled types file named StdAfx.obj.
+ named CellStagePartsAPI.pch and a precompiled types file named StdAfx.obj.
/////////////////////////////////////////////////////////////////////////////
Other notes:
diff --git a/BetterCells/stdafx.cpp b/CellStagePartsAPI/stdafx.cpp
similarity index 80%
rename from BetterCells/stdafx.cpp
rename to CellStagePartsAPI/stdafx.cpp
index c185971..683d621 100644
--- a/BetterCells/stdafx.cpp
+++ b/CellStagePartsAPI/stdafx.cpp
@@ -1,5 +1,5 @@
// stdafx.cpp : source file that includes just the standard includes
-// BetterCells.pch will be the pre-compiled header
+// CellStagePartsAPI.pch will be the pre-compiled header
// stdafx.obj will contain the pre-compiled type information
#include "stdafx.h"
diff --git a/BetterCells/stdafx.h b/CellStagePartsAPI/stdafx.h
similarity index 100%
rename from BetterCells/stdafx.h
rename to CellStagePartsAPI/stdafx.h
diff --git a/BetterCells/targetver.h b/CellStagePartsAPI/targetver.h
similarity index 100%
rename from BetterCells/targetver.h
rename to CellStagePartsAPI/targetver.h
diff --git a/LICENSE b/LICENSE
index 1c0f0f1..61ba2c5 100644
--- a/LICENSE
+++ b/LICENSE
@@ -652,7 +652,7 @@ Also add information on how to contact you by electronic and paper mail.
If the program does terminal interaction, make it output a short
notice like this when it starts in an interactive mode:
- BetterCells Copyright (C) 2018 Zarklord
+ CellStagePartsAPI Copyright (C) 2018 Zarklord
This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
This is free software, and you are welcome to redistribute it
under certain conditions; type `show c' for details.
diff --git a/BetterCells/BetterCells.cpp b/CellStagePartsAPI/CellStagePartsAPI.cpp
similarity index 88%
rename from BetterCells/BetterCells.cpp
rename to CellStagePartsAPI/CellStagePartsAPI.cpp
index 53e09b7..01cf9ad 100644
--- a/BetterCells/BetterCells.cpp
+++ b/CellStagePartsAPI/CellStagePartsAPI.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
* Copyright (C) 2018, 2019 Zarklord
*
-* This file is part of BetterCells.
+* This file is part of CellStagePartsAPI.
*
* BetterCells is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -14,15 +14,15 @@
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
-* along with BetterCells. If not, see .
+* along with CellStagePartsAPI. If not, see .
****************************************************************************/
#include "stdafx.h"
-#include "BetterCells.h"
+#include "CellStagePartsAPI.h"
#include
#include
-namespace BetterCells {
+namespace CellStagePartsAPI {
eastl::vector partlist{};
eastl::list idList{};
int partListSize;
@@ -74,10 +74,10 @@ namespace BetterCells {
}
constexpr auto CELLPARTSGROUPID = 0x40616000;
-void BetterCells::EnterCellEditor_detour::DETOUR(uint32_t* CellDataList) {
+void CellStagePartsAPI::EnterCellEditor_detour::DETOUR(uint32_t* CellDataList) {
uint32_t* ClassPtr;
__volatile __asm mov ClassPtr, EDI; //the this* is stored in EDI, pull it out before it gets clobbered
- if (!BetterCells::wasConfiged) {
+ if (!CellStagePartsAPI::wasConfiged) {
//restore the this* to EDI before calling the original function
__volatile __asm mov EDI, ClassPtr;
return original_function(CellDataList);
@@ -86,7 +86,7 @@ void BetterCells::EnterCellEditor_detour::DETOUR(uint32_t* CellDataList) {
CALL(Address(ModAPI::ChooseAddress(0x5976E0, 0x597A20)), void, Args(uint32_t*), Args(ClassPtr));
CALL(Address(ModAPI::ChooseAddress(0x599100, 0x599440)), void, Args(uint32_t*, int, int, int), Args(ClassPtr, 0, 0, CELLPARTSGROUPID));
*((byte*)ClassPtr + 0xC) = 0;
- for (auto i : BetterCells::partlist) {
+ for (auto i : CellStagePartsAPI::partlist) {
CALL(Address(ModAPI::ChooseAddress(0x598A70, 0x598DB0)), void, Args(uint32_t*, int, int, int, unsigned int, int, int, int, int, int), Args(ClassPtr, i.partinstanceID, 0, 0, 0, 0, 0, 0, 0, 0));
uint32_t isUnlockedValue = CellDataList[i.unlockID];
if (isUnlockedValue == 1) {
@@ -97,7 +97,7 @@ void BetterCells::EnterCellEditor_detour::DETOUR(uint32_t* CellDataList) {
}
}
CALL(Address(ModAPI::ChooseAddress(0x594010, 0x5942E0)), void, Args(uint32_t*), Args(ClassPtr));
- for (auto i : BetterCells::partlist) {
+ for (auto i : CellStagePartsAPI::partlist) {
uint32_t isUnlockedValue = CellDataList[i.unlockID];
if (isUnlockedValue == 2) {
CALL(Address(ModAPI::ChooseAddress(0x596A60, 0x596DA0)), void, Args(uint32_t*, int, int, int), Args(ClassPtr, i.partinstanceID, CELLPARTSGROUPID, 0));
@@ -105,16 +105,16 @@ void BetterCells::EnterCellEditor_detour::DETOUR(uint32_t* CellDataList) {
}
}
-void BetterCells::LeaveCellEditor_detour::DETOUR() {
+void CellStagePartsAPI::LeaveCellEditor_detour::DETOUR() {
uint32_t* ClassPtr;
__volatile __asm mov ClassPtr, EAX; //the this* is stored in EAX, pull it out before it gets clobbered
- if (!BetterCells::wasConfiged) {
+ if (!CellStagePartsAPI::wasConfiged) {
//restore the this* to EAX before calling the original function
__volatile __asm mov EAX, ClassPtr;
return original_function();
}
//2 means display the "new" part effect, 1 just means unlocked.
- for (auto i : BetterCells::idList) {
+ for (auto i : CellStagePartsAPI::idList) {
if (ClassPtr[i] == 2) ClassPtr[i] = 1;
}
}
@@ -1,9 +1,9 @@
*
-* BetterCells is free software: you can redistribute it and/or modify
+* CellStagePartsAPI is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
\ No newline at end of file
diff --git a/BetterCells/BetterCells.h b/CellStagePartsAPI/CellStagePartsAPI.h
similarity index 83%
rename from BetterCells/BetterCells.h
rename to CellStagePartsAPI/CellStagePartsAPI.h
index 804c667..447c652 100644
--- a/BetterCells/BetterCells.h
+++ b/CellStagePartsAPI/CellStagePartsAPI.h
@@ -1,9 +1,9 @@
/****************************************************************************
* Copyright (C) 2018, 2019 Zarklord
*
-* This file is part of BetterCells.
+* This file is part of CellStagePartsAPI.
*
* BetterCells is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -14,7 +14,7 @@
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
-* along with BetterCells. If not, see .
+* along with CellStagePartsAPI. If not, see .
****************************************************************************/
#pragma once
@@ -23,7 +23,7 @@
#include
#include
-namespace BetterCells {
+namespace CellStagePartsAPI {
struct CellPartListKey {
uint32_t unlockID;
uint32_t partinstanceID;
@@ -1,9 +1,9 @@
*
-* BetterCells is free software: you can redistribute it and/or modify
+* CellStagePartsAPI is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
diff --git a/BetterCells/SdkPathConfig.props b/CellStagePartsAPI/SdkPathConfig.props
similarity index 100%
rename from BetterCells/SdkPathConfig.props
rename to CellStagePartsAPI/SdkPathConfig.props
diff --git a/BetterCells/dllmain.cpp b/CellStagePartsAPI/dllmain.cpp
similarity index 85%
rename from BetterCells/dllmain.cpp
rename to CellStagePartsAPI/dllmain.cpp
index ed9b062..49b6432 100644
--- a/BetterCells/dllmain.cpp
+++ b/CellStagePartsAPI/dllmain.cpp
@@ -1,9 +1,9 @@
/****************************************************************************
* Copyright (C) 2018, 2019 Zarklord
*
-* This file is part of BetterCells.
+* This file is part of CellStagePartsAPI.
*
* BetterCells is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -14,12 +14,12 @@
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
-* along with BetterCells. If not, see .
+* along with CellStagePartsAPI. If not, see .
****************************************************************************/
// dllmain.cpp : Defines the entry point for the DLL application.
#include "stdafx.h"
-#include "BetterCells.h"
+#include "CellStagePartsAPI.h"
void Initialize()
{
@@ -30,7 +30,7 @@ void Initialize()
// - Add new game modes
// - Add new space tools
// - Change materials
- BetterCells::Initialize();
+ CellStagePartsAPI::Initialize();
}
void Dispose()
@@ -42,7 +42,7 @@ void AttachDetours()
{
// Call the attach() method on any detours you want to add
// For example: cViewer_SetRenderType_detour::attach(GetAddress(cViewer, SetRenderType));
- BetterCells::AttachDetours();
+ CellStagePartsAPI::AttachDetours();
}
// Generally, you don't need to touch any code here
@@ -1,9 +1,9 @@
*
-* BetterCells is free software: you can redistribute it and/or modify
+* CellStagePartsAPI is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or